@@ -1,43 +1,7 @@
 package API::Google;
-
+$API::Google::VERSION = '0.05';
 # ABSTRACT: Perl library for easy access to Google services via their API
 
-=head1 SYNOPSIS
-
-    use API::Google;
-    my $gapi = API::Google->new({ tokensfile => 'config.json' });
-    
-    $gapi->refresh_access_token_silent('someuser@gmail.com');
-    
-    $gapi->api_query({ 
-      method => 'post', 
-      route => 'https://www.googleapis.com/calendar/v3/calendars/'.$calendar_id.'/events',
-      user => 'someuser@gmail.com'
-    }, $json_payload_if_post);
-
-
-=head1 CONFIGURATION
-
-config.json must be structured like:
-
-  { "gapi":
-    {
-      "client_id": "001122334455-abcdefghijklmnopqrstuvwxyz012345.apps.googleusercontent.com",
-      "client_secret": "1ayL76NlEKjj85eZOipFZkyM",
-      "tokens": {
-          "email_1@gmail.com": {
-              "refresh_token": "1/cI5jWSVnsUyCbasCQpDmz8uhQyfnWWphxvb1ST3oTHE",
-              "access_token": "ya29.Ci-KA8aJYEAyZoxkMsYbbU9H_zj2t9-7u1aKUtrOtak3pDhJvCEPIdkW-xg2lRQdrA"
-          },
-          "email_2@gmail.com": {
-              "access_token": "ya29.Ci-KAzT9JpaPriZ-ugON4FnANBXZexTZOz-E6U4M-hjplbIcMYpTbo0AmGV__tV5FA",
-              "refresh_token": "1/_37lsRFSRaUJkAAAuJIRXRUueft5eLWaIsJ0lkJmEMU"
-          }
-      }
-    }
-  }
-	
-=cut
 
 use strict;
 use warnings;
@@ -59,10 +23,6 @@ sub new {
 }
 
 
-=head1 SUBROUTINES/METHODS
-
-=cut
-
 sub refresh_access_token {
   my ($self, $params) = @_;
   warn Dumper $params;
@@ -85,11 +45,6 @@ sub client_secret {
 }
 
 
-=head2 refresh_access_token_silent
-
-Get new access token for user from Google API server and store it in jsonfile
-
-=cut
 
 sub refresh_access_token_silent {
 	my ($self, $user) = @_;
@@ -125,6 +80,59 @@ sub set_access_token_to_storage {
 };
 
 
+
+
+sub api_query {
+  my ($self, $params, $payload) = @_;
+  my %headers = (
+    'Authorization' => 'Bearer '.$self->get_access_token_from_storage($params->{user})
+  );
+  my $http_method = $params->{method};
+  if ($http_method eq 'get') {
+    return $self->{ua}->$http_method($params->{route} => \%headers)->res->json;
+  } elsif (($http_method eq 'post') && $payload) {
+    return $self->{ua}->$http_method($params->{route} => \%headers => json => $payload)->res->json;
+  } else {
+    die 'wrong http_method';
+  }
+};
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+API::Google - Perl library for easy access to Google services via their API
+
+=head1 VERSION
+
+version 0.05
+
+=head1 SYNOPSIS
+
+    use API::Google;
+    my $gapi = API::Google->new({ tokensfile => 'config.json' });
+    
+    $gapi->refresh_access_token_silent('someuser@gmail.com');
+    
+    $gapi->api_query({ 
+      method => 'post', 
+      route => 'https://www.googleapis.com/calendar/v3/calendars/'.$calendar_id.'/events',
+      user => 'someuser@gmail.com'
+    }, $json_payload_if_post);
+
+=head1 METHODS
+
+=head2 refresh_access_token_silent
+
+Get new access token for user from Google API server and store it in jsonfile
+
 =head2 api_query
 
 Low-level method that can make API query to any Google service
@@ -145,23 +153,36 @@ Examples of usage:
       user => 'someuser@gmail.com'
   }, $json_payload_if_post);
 
-=cut
+=head1 CONFIGURATION
 
+config.json must be structured like:
 
-sub api_query {
-  my ($self, $params, $payload) = @_;
-  my %headers = (
-    'Authorization' => 'Bearer '.$self->get_access_token_from_storage($params->{user})
-  );
-  my $http_method = $params->{method};
-  if ($http_method eq 'get') {
-    return $self->{ua}->$http_method($params->{route} => \%headers)->res->json;
-  } elsif (($http_method eq 'post') && $payload) {
-    return $self->{ua}->$http_method($params->{route} => \%headers => json => $payload)->res->json;
-  } else {
-    die 'wrong http_method';
+  { "gapi":
+    {
+      "client_id": "001122334455-abcdefghijklmnopqrstuvwxyz012345.apps.googleusercontent.com",
+      "client_secret": "1ayL76NlEKjj85eZOipFZkyM",
+      "tokens": {
+          "email_1@gmail.com": {
+              "refresh_token": "1/cI5jWSVnsUyCbasCQpDmz8uhQyfnWWphxvb1ST3oTHE",
+              "access_token": "ya29.Ci-KA8aJYEAyZoxkMsYbbU9H_zj2t9-7u1aKUtrOtak3pDhJvCEPIdkW-xg2lRQdrA"
+          },
+          "email_2@gmail.com": {
+              "access_token": "ya29.Ci-KAzT9JpaPriZ-ugON4FnANBXZexTZOz-E6U4M-hjplbIcMYpTbo0AmGV__tV5FA",
+              "refresh_token": "1/_37lsRFSRaUJkAAAuJIRXRUueft5eLWaIsJ0lkJmEMU"
+          }
+      }
+    }
   }
-};
 
+=head1 AUTHOR
 
-1;
+Pavel Serikov <pavelsr@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Pavel Serikov.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
