@@ -1,10 +1,96 @@
 package API::Google::GCal;
+$API::Google::GCal::VERSION = '0.05';
+
 use parent 'API::Google';
 # use base 'API::Google';
 
 # ABSTRACT: Google Calendar API client
 
 
+
+
+sub new {
+    my ($class, $params) = @_;
+    my $self = API::Google->new($params);
+    $self->{api_base} = 'https://www.googleapis.com/calendar/v3';
+    bless $self, $class;
+    return $self; # just for clearance
+}
+
+
+sub get_calendars {
+  my ($self, $user, $fields) = @_;
+  my $res = $self->api_query({ 
+  	method => 'get', 
+  	route => $self->{api_base}.'/users/me/calendarList',
+  	user => $user
+  });
+
+  if ($fields) {
+    my @a;
+    for my $item (@{$res->{items}}) {
+        push @a, { map { $_ => $item->{$_} } grep { exists $item->{$_} } @$fields }; 
+    }
+    return \@a;
+  } else {
+    return $res;
+  }
+}
+
+
+sub get_calendar_id_by_name {
+    my ($self, $user, $name) = @_;
+    my $all = $self->get_calendars($user, ['id', 'summary']);   # arr ref
+    my @n = grep { $_->{'summary'} eq $name } @$all;
+    my $full_id = $n[0]->{id};
+    return $full_id;
+}
+
+
+
+sub add_event {
+    my ($self, $user, $calendar_id, $event_data) = @_;
+    $self->api_query({ 
+      method => 'post', 
+      route => $self->{api_base}.'/calendars/'.$calendar_id.'/events',
+      user => $user
+    }, $event_data);
+}
+
+
+
+sub busy_time_ranges {
+   my ($self, $params) = @_;
+    $self->api_query({ 
+      method => 'post', 
+      route => $self->{api_base}.'/freeBusy',
+      user => $params->{user}
+    }, {
+      timeMin => $params->{dt_start},
+      timeMax => $params->{dt_end},
+      timeZone => $params->{timeZone},
+      items => [{ 'id' => $params->{calendar_id} }]
+    });
+};
+
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+API::Google::GCal - Google Calendar API client
+
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
     use API::Google::GCal;
@@ -42,96 +128,32 @@ use parent 'API::Google';
     };
 
     $gapi->busy_time_ranges($freebusy_data);
-    
-  
-=cut
-
-
-sub new {
-    my ($class, $params) = @_;
-    my $self = API::Google->new($params);
-    $self->{api_base} = 'https://www.googleapis.com/calendar/v3';
-    bless $self, $class;
-    return $self; # just for clearance
-}
 
 =head2 get_calendars
 
 Get all calendars of particular Google account
 
-=cut
-
-sub get_calendars {
-  my ($self, $user, $fields) = @_;
-  my $res = $self->api_query({ 
-  	method => 'get', 
-  	route => $self->{api_base}.'/users/me/calendarList',
-  	user => $user
-  });
-
-  if ($fields) {
-    my @a;
-    for my $item (@{$res->{items}}) {
-        push @a, { map { $_ => $item->{$_} } grep { exists $item->{$_} } @$fields }; 
-    }
-    return \@a;
-  } else {
-    return $res;
-  }
-}
-
 =head2 get_calendar_id_by_name
 
 Get calendar id by its name. Name = "summary" parameter
 
-=cut
-
-sub get_calendar_id_by_name {
-    my ($self, $user, $name) = @_;
-    my $all = $self->get_calendars($user, ['id', 'summary']);   # arr ref
-    my @n = grep { $_->{'summary'} eq $name } @$all;
-    my $full_id = $n[0]->{id};
-    return $full_id;
-}
-
-
 =head2 add_event
 
 # https://developers.google.com/google-apps/calendar/v3/reference/events/insert
 
-=cut
-
-sub add_event {
-    my ($self, $user, $calendar_id, $event_data) = @_;
-    $self->api_query({ 
-      method => 'post', 
-      route => $self->{api_base}.'/calendars/'.$calendar_id.'/events',
-      user => $user
-    }, $event_data);
-}
-
-
 =head2 busy_time_ranges
 
 Return List of time ranges during which this calendar should be regarded as busy. 
 
+=head1 AUTHOR
+
+Pavel Serikov <pavelsr@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Pavel Serikov.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-sub busy_time_ranges {
-   my ($self, $params) = @_;
-    $self->api_query({ 
-      method => 'post', 
-      route => $self->{api_base}.'/freeBusy',
-      user => $params->{user}
-    }, {
-      timeMin => $params->{dt_start},
-      timeMax => $params->{dt_end},
-      timeZone => $params->{timeZone},
-      items => [{ 'id' => $params->{calendar_id} }]
-    });
-};
-
-
-
-1;
-
